import { API, } from '@infinite-canvas-tutorial/ecs';
import { Event } from './event';
/**
 * Since the canvas is created in the system, we need to store them here for later use.
 */
export const pendingCanvases = [];
/**
 * Emit CustomEvents for the canvas.
 */
export class ExtendedAPI extends API {
    constructor(stateManagement, commands, element) {
        super(stateManagement, commands);
        this.element = element;
    }
    resizeCanvas(width, height) {
        super.resizeCanvas(width, height);
        this.element.dispatchEvent(new CustomEvent(Event.RESIZED, { detail: { width, height } }));
    }
    setCheckboardStyle(checkboardStyle) {
        super.setCheckboardStyle(checkboardStyle);
        this.element.dispatchEvent(new CustomEvent(Event.CHECKBOARD_STYLE_CHANGED, {
            detail: { checkboardStyle },
        }));
    }
    setPen(pen) {
        super.setPen(pen);
        this.element.dispatchEvent(new CustomEvent(Event.PEN_CHANGED, {
            detail: { selected: [pen] },
        }));
    }
    setTaskbars(selected) {
        super.setTaskbars(selected);
        this.element.dispatchEvent(new CustomEvent(Event.TASK_CHANGED, { detail: { selected } }));
    }
    selectNodes(selected, preserveSelection = false) {
        super.selectNodes(selected, preserveSelection);
        this.element.dispatchEvent(new CustomEvent(Event.SELECTED_NODES_CHANGED, {
            detail: { selected, preserveSelection },
        }));
    }
    updateNodes(nodes) {
        super.updateNodes(nodes);
        this.element.dispatchEvent(new CustomEvent(Event.NODES_UPDATED, {
            detail: {
                nodes,
            },
        }));
    }
    deleteNodesById(ids) {
        const nodes = super.deleteNodesById(ids);
        this.element.dispatchEvent(new CustomEvent(Event.NODE_DELETED, {
            detail: {
                nodes,
            },
        }));
        return nodes;
    }
    /**
     * Delete Canvas component
     */
    destroy() {
        super.destroy();
        this.element.dispatchEvent(new CustomEvent(Event.DESTROY));
    }
}
//# sourceMappingURL=API.js.map