var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { css, html, LitElement } from 'lit';
import { customElement, property } from 'lit/decorators.js';
import { when } from 'lit/directives/when.js';
import { unsafeSVG } from 'lit/directives/unsafe-svg.js';
import { ComputedBounds, exportFillGradientOrPattern, isGradient, isPattern, createSVGElement, } from '@infinite-canvas-tutorial/ecs';
import { consume } from '@lit/context';
import { apiContext } from '../context';
const THUMBNAIL_SIZE = 52;
// const THUMBNAIL_PADDING = 4;
let LayerThumbnail = class LayerThumbnail extends LitElement {
    constructor() {
        super(...arguments);
        this.selected = false;
    }
    render() {
        const entity = this.api.getEntity(this.node);
        if (!entity.has(ComputedBounds)) {
            return;
        }
        const { minX, minY, maxX, maxY } = entity.read(ComputedBounds).renderBounds;
        const width = maxX - minX;
        const height = maxY - minY;
        const transform = `translate(${-minX - width / 2}, ${-minY - height / 2})`;
        let $el;
        const { type } = this.node;
        if (type === 'ellipse') {
            $el = createSVGElement('ellipse');
            $el.setAttribute('cx', `${minX + width / 2}`);
            $el.setAttribute('cy', `${minY + height / 2}`);
            $el.setAttribute('rx', `${width / 2}`);
            $el.setAttribute('ry', `${height / 2}`);
        }
        else if (type === 'rect') {
            $el = createSVGElement('rect');
            $el.setAttribute('x', `${minX}`);
            $el.setAttribute('y', `${minY}`);
            $el.setAttribute('width', `${width}`);
            $el.setAttribute('height', `${height}`);
        }
        else if (type === 'path') {
            $el = createSVGElement('path');
            $el.setAttribute('d', this.node.d);
        }
        else if (type === 'polyline') {
            $el = createSVGElement('polyline');
            $el.setAttribute('points', this.node.points);
        }
        const { fill, stroke, strokeWidth, strokeLinecap, strokeLinejoin, strokeMiterlimit, strokeDasharray, strokeDashoffset, } = this.node;
        if ($el) {
            $el.setAttribute('transform', transform);
            if (fill) {
                $el.setAttribute('fill', fill);
            }
            if (stroke) {
                $el.setAttribute('stroke', stroke);
            }
            if (strokeWidth) {
                $el.setAttribute('stroke-width', strokeWidth.toString());
            }
            if (strokeLinecap) {
                $el.setAttribute('stroke-linecap', strokeLinecap);
            }
            if (strokeLinejoin) {
                $el.setAttribute('stroke-linejoin', strokeLinejoin);
            }
            if (strokeMiterlimit) {
                $el.setAttribute('stroke-miterlimit', strokeMiterlimit.toString());
            }
            if (strokeDasharray) {
                $el.setAttribute('stroke-dasharray', strokeDasharray);
            }
            if (strokeDashoffset) {
                $el.setAttribute('stroke-dashoffset', strokeDashoffset.toString());
            }
        }
        const isGradientOrPattern = isGradient(fill) || isPattern(fill);
        let defsHTML = '';
        if (isGradientOrPattern) {
            const $g = createSVGElement('g');
            exportFillGradientOrPattern(Object.assign({}, this.node), $el, $g);
            defsHTML = $g.children[0].innerHTML;
        }
        return html `<sp-thumbnail size="1000" ?focused=${this.selected}>
      ${when(this.node.type === 'text', () => html `<sp-icon-text></sp-icon-text>`, () => html `<svg
          viewBox="${-width / 2} ${-height / 2} ${width} ${height}"
        >
          ${unsafeSVG(defsHTML)} ${unsafeSVG($el.outerHTML)}
        </svg>`)}
    </sp-thumbnail>`;
    }
};
LayerThumbnail.styles = css `
    :host {
    }

    svg {
      display: block;
      width: ${THUMBNAIL_SIZE}px;
      height: ${THUMBNAIL_SIZE}px;
      box-sizing: border-box;
      overflow: hidden;
    }

    sp-icon-text {
      display: block;
    }
  `;
__decorate([
    consume({ context: apiContext, subscribe: true })
], LayerThumbnail.prototype, "api", void 0);
__decorate([
    property()
], LayerThumbnail.prototype, "node", void 0);
__decorate([
    property({ type: Boolean })
], LayerThumbnail.prototype, "selected", void 0);
LayerThumbnail = __decorate([
    customElement('ic-spectrum-layer-thumbnail')
], LayerThumbnail);
export { LayerThumbnail };
//# sourceMappingURL=layer-thumbnail.js.map