var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { html, css, LitElement } from 'lit';
import { customElement } from 'lit/decorators.js';
import { map } from 'lit/directives/map.js';
import { when } from 'lit/directives/when.js';
import { consume } from '@lit/context';
import { apiContext, appStateContext } from '../context';
import { Pen, Task } from '@infinite-canvas-tutorial/ecs';
const TaskMap = {
    [Task.SHOW_LAYERS_PANEL]: {
        icon: html `<sp-icon-layers slot="icon"></sp-icon-layers>`,
        label: 'Show layers panel',
    },
    [Task.SHOW_PROPERTIES_PANEL]: {
        icon: html `<sp-icon-properties slot="icon"></sp-icon-properties>`,
        label: 'Show properties panel',
    },
};
let Taskbar = class Taskbar extends LitElement {
    handleTaskChanged(e) {
        this.api.setTaskbars(e.target.selected);
    }
    render() {
        const { taskbarAll, taskbarSelected, taskbarVisible } = this.appState;
        return when(taskbarVisible && this.appState.penbarSelected[0] !== Pen.HAND, () => html `
        <sp-action-group
          class="taskbar"
          vertical
          quiet
          selects="multiple"
          .selected=${taskbarSelected}
          @change=${this.handleTaskChanged}
        >
          ${map(taskbarAll, (task) => {
            const { icon, label } = TaskMap[task];
            return html `<sp-action-button value="${task}">
              ${icon}
              <sp-tooltip self-managed placement="left"> ${label} </sp-tooltip>
            </sp-action-button>`;
        })}
        </sp-action-group>
        <div class="panels">
          <ic-spectrum-layers-panel></ic-spectrum-layers-panel>
          <ic-spectrum-properties-panel></ic-spectrum-properties-panel>
        </div>
      `);
    }
};
Taskbar.styles = css `
    .taskbar {
      display: flex;
      background: var(--spectrum-gray-100);
      border-radius: var(--spectrum-corner-radius-200);
      justify-content: center;

      padding: var(--spectrum-global-dimension-size-100);
      margin: 4px;

      filter: drop-shadow(
        var(--spectrum-drop-shadow-color) 0px var(--spectrum-drop-shadow-y)
          var(--spectrum-drop-shadow-blur)
      );
    }

    .panels {
      position: absolute;
      top: 0px;
      right: 54px;
      display: flex;
      flex-direction: column;
      z-index: 1;
    }
  `;
__decorate([
    consume({ context: appStateContext, subscribe: true })
], Taskbar.prototype, "appState", void 0);
__decorate([
    consume({ context: apiContext, subscribe: true })
], Taskbar.prototype, "api", void 0);
Taskbar = __decorate([
    customElement('ic-spectrum-taskbar')
], Taskbar);
export { Taskbar };
//# sourceMappingURL=taskbar.js.map