var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { html, css, LitElement } from 'lit';
import { customElement } from 'lit/decorators.js';
import { when } from 'lit/directives/when.js';
import { consume } from '@lit/context';
import { CheckboardStyle } from '@infinite-canvas-tutorial/ecs';
import { apiContext, appStateContext } from '../context';
export var ExportFormat;
(function (ExportFormat) {
    ExportFormat["SVG"] = "svg";
    ExportFormat["PNG"] = "png";
    ExportFormat["JPEG"] = "jpeg";
})(ExportFormat || (ExportFormat = {}));
let TopNavbar = class TopNavbar extends LitElement {
    constructor() {
        super(...arguments);
        this.handleKeyDown = (e) => {
            // Canvas is focused
            if (document.activeElement !== this.api.element) {
                return;
            }
            if (e.key === 'z' && e.metaKey) {
                e.preventDefault();
                if (e.shiftKey) {
                    this.handleRedo();
                }
                else {
                    this.handleUndo();
                }
            }
        };
    }
    connectedCallback() {
        super.connectedCallback();
        document.addEventListener('keydown', this.handleKeyDown);
    }
    disconnectedCallback() {
        super.disconnectedCallback();
        document.removeEventListener('keydown', this.handleKeyDown);
    }
    handleExport(event) {
        const format = event.target.value;
        this.api.export(format);
    }
    handleEdit(event) {
        const value = event.target.value;
        if (value === 'undo') {
            this.handleUndo();
        }
        else if (value === 'redo') {
            this.handleRedo();
        }
    }
    handleConfigView(event) {
        const value = event.target.value;
        if (value === 'grid') {
            this.api.setCheckboardStyle(CheckboardStyle.GRID);
        }
        else {
            this.api.setCheckboardStyle(CheckboardStyle.NONE);
        }
    }
    handleUndo() {
        this.api.undo();
    }
    handleRedo() {
        this.api.redo();
    }
    render() {
        return when(this.appState.topbarVisible, () => {
            var _a, _b, _c, _d;
            return html `
          <div class="top-navbar">
            <sp-action-menu size="m" label="Main menu" quiet>
              <sp-tooltip slot="tooltip" self-managed placement="bottom">
                Main menu
              </sp-tooltip>
              <sp-icon-show-menu slot="icon" size="l"></sp-icon-show-menu>
              <sp-menu-item>
                Edit
                <sp-menu slot="submenu" @change=${this.handleEdit}>
                  <sp-menu-item
                    value="undo"
                    ?disabled=${(_a = this.api) === null || _a === void 0 ? void 0 : _a.isUndoStackEmpty()}
                  >
                    Undo
                    <kbd slot="value">⌘Z</kbd>
                  </sp-menu-item>
                  <sp-menu-item
                    value="redo"
                    ?disabled=${(_b = this.api) === null || _b === void 0 ? void 0 : _b.isRedoStackEmpty()}
                  >
                    Redo
                    <kbd slot="value">⇧⌘Z</kbd>
                  </sp-menu-item>
                  <sp-menu-divider></sp-menu-divider>
                  <sp-menu-item value="cut">
                    Cut
                    <kbd slot="value">⌘X</kbd>
                  </sp-menu-item>
                  <sp-menu-item value="copy">
                    Copy
                    <kbd slot="value">⌘C</kbd>
                  </sp-menu-item>
                  <sp-menu-item value="paste">
                    Paste
                    <kbd slot="value">⌘V</kbd>
                  </sp-menu-item>
                </sp-menu>
              </sp-menu-item>
              <sp-menu-item>
                View
                <sp-menu
                  slot="submenu"
                  selects="multiple"
                  .selected=${this.appState.checkboardStyle ===
                CheckboardStyle.GRID
                ? ['grid']
                : []}
                  @change=${this.handleConfigView}
                >
                  <sp-menu-item value="grid"> Grid </sp-menu-item>
                </sp-menu>
              </sp-menu-item>
              <sp-menu-divider></sp-menu-divider>
              <sp-menu-item>
                Export as...
                <sp-menu slot="submenu" @change=${this.handleExport}>
                  <sp-menu-item value=${ExportFormat.SVG}>SVG</sp-menu-item>
                  <sp-menu-item value=${ExportFormat.PNG}>PNG</sp-menu-item>
                  <sp-menu-item value=${ExportFormat.JPEG}>JPEG</sp-menu-item>
                </sp-menu>
              </sp-menu-item>
            </sp-action-menu>
            <div class="actions">
              <sp-action-button
                quiet
                @click=${this.handleUndo}
                ?disabled=${(_c = this.api) === null || _c === void 0 ? void 0 : _c.isUndoStackEmpty()}
              >
                <sp-icon-undo slot="icon"></sp-icon-undo>
                <sp-tooltip self-managed placement="bottom"> Undo </sp-tooltip>
              </sp-action-button>
              <sp-action-button
                quiet
                @click=${this.handleRedo}
                ?disabled=${(_d = this.api) === null || _d === void 0 ? void 0 : _d.isRedoStackEmpty()}
              >
                <sp-icon-redo slot="icon"></sp-icon-redo>
                <sp-tooltip self-managed placement="bottom"> Redo </sp-tooltip>
              </sp-action-button>
              <ic-spectrum-zoom-toolbar />
            </div>
          </div>
        `;
        });
    }
};
TopNavbar.styles = css `
    .top-navbar {
      display: flex;
      justify-content: space-between;
      padding: var(--spectrum-global-dimension-size-100);
      background: var(--spectrum-gray-100);
    }

    sp-menu-item {
      width: 200px;
    }

    kbd {
      font-family: var(--spectrum-alias-body-text-font-family);
      letter-spacing: 0.1em;
      white-space: nowrap;
      border: none;
      padding: none;
      padding: 0;
      line-height: normal;
    }

    .actions {
      display: flex;
      align-items: center;
      gap: var(--spectrum-global-dimension-size-100);
    }
  `;
__decorate([
    consume({ context: appStateContext, subscribe: true })
], TopNavbar.prototype, "appState", void 0);
__decorate([
    consume({ context: apiContext, subscribe: true })
], TopNavbar.prototype, "api", void 0);
TopNavbar = __decorate([
    customElement('ic-spectrum-top-navbar')
], TopNavbar);
export { TopNavbar };
//# sourceMappingURL=top-navbar.js.map