"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExtendedAPI = exports.pendingCanvases = void 0;
const ecs_1 = require("@infinite-canvas-tutorial/ecs");
const event_1 = require("./event");
/**
 * Since the canvas is created in the system, we need to store them here for later use.
 */
exports.pendingCanvases = [];
/**
 * Emit CustomEvents for the canvas.
 */
class ExtendedAPI extends ecs_1.API {
    constructor(stateManagement, commands, element) {
        super(stateManagement, commands);
        this.element = element;
    }
    resizeCanvas(width, height) {
        super.resizeCanvas(width, height);
        this.element.dispatchEvent(new CustomEvent(event_1.Event.RESIZED, { detail: { width, height } }));
    }
    setCheckboardStyle(checkboardStyle) {
        super.setCheckboardStyle(checkboardStyle);
        this.element.dispatchEvent(new CustomEvent(event_1.Event.CHECKBOARD_STYLE_CHANGED, {
            detail: { checkboardStyle },
        }));
    }
    setPen(pen) {
        super.setPen(pen);
        this.element.dispatchEvent(new CustomEvent(event_1.Event.PEN_CHANGED, {
            detail: { selected: [pen] },
        }));
    }
    setTaskbars(selected) {
        super.setTaskbars(selected);
        this.element.dispatchEvent(new CustomEvent(event_1.Event.TASK_CHANGED, { detail: { selected } }));
    }
    selectNodes(selected, preserveSelection = false) {
        super.selectNodes(selected, preserveSelection);
        this.element.dispatchEvent(new CustomEvent(event_1.Event.SELECTED_NODES_CHANGED, {
            detail: { selected, preserveSelection },
        }));
    }
    updateNodes(nodes) {
        super.updateNodes(nodes);
        this.element.dispatchEvent(new CustomEvent(event_1.Event.NODES_UPDATED, {
            detail: {
                nodes,
            },
        }));
    }
    deleteNodesById(ids) {
        const nodes = super.deleteNodesById(ids);
        this.element.dispatchEvent(new CustomEvent(event_1.Event.NODE_DELETED, {
            detail: {
                nodes,
            },
        }));
        return nodes;
    }
    /**
     * Delete Canvas component
     */
    destroy() {
        super.destroy();
        this.element.dispatchEvent(new CustomEvent(event_1.Event.DESTROY));
    }
}
exports.ExtendedAPI = ExtendedAPI;
//# sourceMappingURL=API.js.map