"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContextBar = void 0;
const lit_1 = require("lit");
const decorators_js_1 = require("lit/decorators.js");
const when_js_1 = require("lit/directives/when.js");
const context_1 = require("@lit/context");
const ecs_1 = require("@infinite-canvas-tutorial/ecs");
const context_2 = require("../context");
const infinite_canvas_1 = require("./infinite-canvas");
const CONTEXT_BAR_MARGIN_BOTTOM = 16;
let ContextBar = class ContextBar extends lit_1.LitElement {
    constructor() {
        super(...arguments);
        this.handleKeyDown = (e) => {
            const { layersSelected } = this.appState;
            // Canvas is focused
            if (document.activeElement !== this.api.element ||
                layersSelected.length === 0) {
                return;
            }
            const selected = this.api.getNodeById(layersSelected[0]);
            if (e.key === 'ArrowUp') {
                e.preventDefault();
                this.api.updateNodeOBB(selected, { y: selected.y - 10 });
                this.api.record();
            }
            else if (e.key === 'ArrowDown') {
                e.preventDefault();
                this.api.updateNodeOBB(selected, { y: selected.y + 10 });
                this.api.record();
            }
            else if (e.key === 'ArrowLeft') {
                e.preventDefault();
                this.api.updateNodeOBB(selected, { x: selected.x - 10 });
                this.api.record();
            }
            else if (e.key === 'ArrowRight') {
                e.preventDefault();
                this.api.updateNodeOBB(selected, { x: selected.x + 10 });
                this.api.record();
            }
        };
    }
    connectedCallback() {
        super.connectedCallback();
        document.addEventListener('keydown', this.handleKeyDown);
    }
    disconnectedCallback() {
        super.disconnectedCallback();
        document.removeEventListener('keydown', this.handleKeyDown);
    }
    calculatePosition(node) {
        const { width, height } = this.api.getCanvas().read(ecs_1.Canvas);
        const { topbarVisible } = this.appState;
        const entity = this.api.getEntity(node);
        if (!entity.has(ecs_1.ComputedBounds)) {
            return [0, 0];
        }
        const { bounds } = entity.read(ecs_1.ComputedBounds);
        const { minX, minY, maxX, maxY } = bounds;
        const tl = this.api.canvas2Viewport({ x: minX, y: minY });
        const br = this.api.canvas2Viewport({ x: maxX, y: maxY });
        return [
            Math.min(width, Math.max(0, tl.x + (br.x - tl.x) / 2)),
            Math.min(height, Math.max(0, tl.y +
                (br.y - tl.y) +
                (topbarVisible ? infinite_canvas_1.TOP_NAVBAR_HEIGHT : 0) +
                CONTEXT_BAR_MARGIN_BOTTOM)),
        ];
    }
    render() {
        const { layersSelected, contextBarVisible } = this.appState;
        const node = layersSelected[0] && this.api.getNodeById(layersSelected[0]);
        const isText = (node === null || node === void 0 ? void 0 : node.type) === 'text';
        return (0, lit_1.html) `${(0, when_js_1.when)(contextBarVisible && layersSelected.length > 0, () => {
            const [left, top] = this.calculatePosition(node);
            return (0, lit_1.html) ` <div class="wrapper" style="left: ${left}px; top: ${top}px;">
        <div class="bar">
          <ic-spectrum-fill-action-button
            .node=${node}
          ></ic-spectrum-fill-action-button>
          ${(0, when_js_1.when)(!isText, () => (0, lit_1.html) `<ic-spectrum-stroke-action-button
                .node=${node}
              ></ic-spectrum-stroke-action-button>
              <sp-action-button quiet size="m" id="stroke-options">
                <sp-tooltip self-managed placement="bottom">
                  Stroke options
                </sp-tooltip>
                <sp-icon-stroke-width slot="icon"></sp-icon-stroke-width>
              </sp-action-button>
              <sp-overlay
                trigger="stroke-options@click"
                placement="bottom"
                type="auto"
              >
                <sp-popover dialog>
                  <h4>Stroke options</h4>
                  <ic-spectrum-stroke-content
                    .node=${node}
                  ></ic-spectrum-stroke-content>
                </sp-popover>
              </sp-overlay>`)}
        </div>
      </div>`;
        })}`;
    }
};
exports.ContextBar = ContextBar;
ContextBar.styles = (0, lit_1.css) `
    .wrapper {
      position: absolute;
      top: 0;
      left: 0;
    }

    .bar {
      transform: translateX(-50%);
      position: absolute;
      left: -50%;

      display: flex;
      justify-content: center;

      background: var(--spectrum-gray-100);
      border-radius: var(--spectrum-corner-radius-200);

      padding: var(--spectrum-global-dimension-size-100);
      margin: 4px;

      filter: drop-shadow(
        var(--spectrum-drop-shadow-color) 0px var(--spectrum-drop-shadow-y)
          var(--spectrum-drop-shadow-blur)
      );
    }

    sp-popover {
      padding: 0;
    }

    h4 {
      margin: 0;
      padding: 8px;
      padding-bottom: 0;
    }

    ic-spectrum-stroke-content {
      padding: 8px;
    }
  `;
__decorate([
    (0, context_1.consume)({ context: context_2.appStateContext, subscribe: true })
], ContextBar.prototype, "appState", void 0);
__decorate([
    (0, context_1.consume)({ context: context_2.apiContext, subscribe: true })
], ContextBar.prototype, "api", void 0);
exports.ContextBar = ContextBar = __decorate([
    (0, decorators_js_1.customElement)('ic-spectrum-context-bar')
], ContextBar);
//# sourceMappingURL=context-bar.js.map