"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LayerThumbnail = void 0;
const lit_1 = require("lit");
const decorators_js_1 = require("lit/decorators.js");
const when_js_1 = require("lit/directives/when.js");
const unsafe_svg_js_1 = require("lit/directives/unsafe-svg.js");
const ecs_1 = require("@infinite-canvas-tutorial/ecs");
const context_1 = require("@lit/context");
const context_2 = require("../context");
const THUMBNAIL_SIZE = 52;
// const THUMBNAIL_PADDING = 4;
let LayerThumbnail = class LayerThumbnail extends lit_1.LitElement {
    constructor() {
        super(...arguments);
        this.selected = false;
    }
    render() {
        const entity = this.api.getEntity(this.node);
        if (!entity.has(ecs_1.ComputedBounds)) {
            return;
        }
        const { minX, minY, maxX, maxY } = entity.read(ecs_1.ComputedBounds).renderBounds;
        const width = maxX - minX;
        const height = maxY - minY;
        const transform = `translate(${-minX - width / 2}, ${-minY - height / 2})`;
        let $el;
        const { type } = this.node;
        if (type === 'ellipse') {
            $el = (0, ecs_1.createSVGElement)('ellipse');
            $el.setAttribute('cx', `${minX + width / 2}`);
            $el.setAttribute('cy', `${minY + height / 2}`);
            $el.setAttribute('rx', `${width / 2}`);
            $el.setAttribute('ry', `${height / 2}`);
        }
        else if (type === 'rect') {
            $el = (0, ecs_1.createSVGElement)('rect');
            $el.setAttribute('x', `${minX}`);
            $el.setAttribute('y', `${minY}`);
            $el.setAttribute('width', `${width}`);
            $el.setAttribute('height', `${height}`);
        }
        else if (type === 'path') {
            $el = (0, ecs_1.createSVGElement)('path');
            $el.setAttribute('d', this.node.d);
        }
        else if (type === 'polyline') {
            $el = (0, ecs_1.createSVGElement)('polyline');
            $el.setAttribute('points', this.node.points);
        }
        const { fill, stroke, strokeWidth, strokeLinecap, strokeLinejoin, strokeMiterlimit, strokeDasharray, strokeDashoffset, } = this.node;
        if ($el) {
            $el.setAttribute('transform', transform);
            if (fill) {
                $el.setAttribute('fill', fill);
            }
            if (stroke) {
                $el.setAttribute('stroke', stroke);
            }
            if (strokeWidth) {
                $el.setAttribute('stroke-width', strokeWidth.toString());
            }
            if (strokeLinecap) {
                $el.setAttribute('stroke-linecap', strokeLinecap);
            }
            if (strokeLinejoin) {
                $el.setAttribute('stroke-linejoin', strokeLinejoin);
            }
            if (strokeMiterlimit) {
                $el.setAttribute('stroke-miterlimit', strokeMiterlimit.toString());
            }
            if (strokeDasharray) {
                $el.setAttribute('stroke-dasharray', strokeDasharray);
            }
            if (strokeDashoffset) {
                $el.setAttribute('stroke-dashoffset', strokeDashoffset.toString());
            }
        }
        const isGradientOrPattern = (0, ecs_1.isGradient)(fill) || (0, ecs_1.isPattern)(fill);
        let defsHTML = '';
        if (isGradientOrPattern) {
            const $g = (0, ecs_1.createSVGElement)('g');
            (0, ecs_1.exportFillGradientOrPattern)(Object.assign({}, this.node), $el, $g);
            defsHTML = $g.children[0].innerHTML;
        }
        return (0, lit_1.html) `<sp-thumbnail size="1000" ?focused=${this.selected}>
      ${(0, when_js_1.when)(this.node.type === 'text', () => (0, lit_1.html) `<sp-icon-text></sp-icon-text>`, () => (0, lit_1.html) `<svg
          viewBox="${-width / 2} ${-height / 2} ${width} ${height}"
        >
          ${(0, unsafe_svg_js_1.unsafeSVG)(defsHTML)} ${(0, unsafe_svg_js_1.unsafeSVG)($el.outerHTML)}
        </svg>`)}
    </sp-thumbnail>`;
    }
};
exports.LayerThumbnail = LayerThumbnail;
LayerThumbnail.styles = (0, lit_1.css) `
    :host {
    }

    svg {
      display: block;
      width: ${THUMBNAIL_SIZE}px;
      height: ${THUMBNAIL_SIZE}px;
      box-sizing: border-box;
      overflow: hidden;
    }

    sp-icon-text {
      display: block;
    }
  `;
__decorate([
    (0, context_1.consume)({ context: context_2.apiContext, subscribe: true })
], LayerThumbnail.prototype, "api", void 0);
__decorate([
    (0, decorators_js_1.property)()
], LayerThumbnail.prototype, "node", void 0);
__decorate([
    (0, decorators_js_1.property)({ type: Boolean })
], LayerThumbnail.prototype, "selected", void 0);
exports.LayerThumbnail = LayerThumbnail = __decorate([
    (0, decorators_js_1.customElement)('ic-spectrum-layer-thumbnail')
], LayerThumbnail);
//# sourceMappingURL=layer-thumbnail.js.map