"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LayersPanel = void 0;
const lit_1 = require("lit");
const context_1 = require("@lit/context");
const map_js_1 = require("lit/directives/map.js");
const decorators_js_1 = require("lit/decorators.js");
const ecs_1 = require("@infinite-canvas-tutorial/ecs");
const context_2 = require("../context");
const event_1 = require("../event");
let LayersPanel = class LayersPanel extends lit_1.LitElement {
    connectedCallback() {
        super.connectedCallback();
        this.api.element.addEventListener(event_1.Event.SELECTED_NODES_CHANGED, (e) => {
            const { selected } = e.detail;
            // Scroll to the selected layer
            if (selected.length > 0) {
                const scrollToId = this.generateLayersPanelItemId(selected[0]);
                const scrollToElement = this.shadowRoot.querySelector(`#${scrollToId}`);
                if (scrollToElement) {
                    scrollToElement.scrollIntoView({
                        behavior: 'smooth',
                        block: 'center',
                    });
                }
            }
        });
    }
    generateLayersPanelItemId(node) {
        return `layers-panel-item-${node.id}`;
    }
    handleClose() {
        this.api.setTaskbars(this.appState.taskbarSelected.filter((task) => task !== ecs_1.Task.SHOW_LAYERS_PANEL));
    }
    handleDelete() {
        const { layersSelected } = this.api.getAppState();
        this.api.deleteNodesById(layersSelected);
        // Try to select the next layer
        const nextLayer = this.nodes.find((node) => !layersSelected.includes(node.id));
        if (nextLayer) {
            this.api.selectNodes([nextLayer]);
        }
        this.api.record();
    }
    handleAdd() {
        // this.api.addNodes(this.nodes);
    }
    handleSelect(e, id) {
        const { layersSelected } = this.api.getAppState();
        if (layersSelected.length === 1 && layersSelected.includes(id)) {
            return;
        }
        const node = this.api.getNodeById(id);
        this.api.selectNodes([node], e.shiftKey);
        this.api.record();
    }
    handleBringToFront() {
        const { layersSelected } = this.api.getAppState();
        const node = this.api.getNodeById(layersSelected[0]);
        this.api.bringToFront(node);
        this.api.record();
        this.api.selectNodes([node]);
    }
    handleBringForward() {
        const { layersSelected } = this.api.getAppState();
        const node = this.api.getNodeById(layersSelected[0]);
        this.api.bringForward(node);
        this.api.record();
        this.api.selectNodes([node]);
    }
    handleSendBackward() {
        const { layersSelected } = this.api.getAppState();
        const node = this.api.getNodeById(layersSelected[0]);
        this.api.sendBackward(node);
        this.api.record();
        this.api.selectNodes([node]);
    }
    handleSendToBack() {
        const { layersSelected } = this.api.getAppState();
        const node = this.api.getNodeById(layersSelected[0]);
        this.api.sendToBack(node);
        this.api.record();
        this.api.selectNodes([node]);
    }
    render() {
        const { layersSelected, taskbarSelected } = this.appState;
        const sortedNodes = this.nodes
            .map((node) => {
            return this.api.getEntity(node);
        })
            .sort(ecs_1.sortByFractionalIndex)
            .map((entity) => {
            return this.api.getNodeByEntity(entity);
        })
            .reverse();
        return taskbarSelected.includes(ecs_1.Task.SHOW_LAYERS_PANEL)
            ? (0, lit_1.html) `<section>
          <h4>
            Layers
            <sp-action-button quiet size="s" @click=${this.handleClose}>
              <sp-icon-close slot="icon"></sp-icon-close>
            </sp-action-button>
          </h4>
          <sp-action-group class="actions">
            <sp-action-button quiet size="s" @click=${this.handleAdd}>
              <sp-tooltip self-managed placement="bottom">
                Add new layer
              </sp-tooltip>
              <sp-icon-add slot="icon"></sp-icon-add>
            </sp-action-button>

            <sp-action-menu
              label="Arrange layers"
              quiet
              size="s"
              .disabled=${layersSelected.length === 0}
            >
              <sp-icon-show-all-layers slot="icon"></sp-icon-show-all-layers>
              <sp-menu-group>
                <span slot="header">Arrange layers</span>
                <sp-menu-item @click=${this.handleBringToFront}>
                  <sp-icon-layers-bring-to-front
                    slot="icon"
                  ></sp-icon-layers-bring-to-front>
                  Bring to front
                </sp-menu-item>
                <sp-menu-item @click=${this.handleBringForward}>
                  <sp-icon-layers-forward slot="icon"></sp-icon-layers-forward>
                  Bring forward
                </sp-menu-item>
                <sp-menu-item @click=${this.handleSendBackward}>
                  <sp-icon-layers-backward
                    slot="icon"
                  ></sp-icon-layers-backward>
                  Send backward
                </sp-menu-item>
                <sp-menu-item @click=${this.handleSendToBack}>
                  <sp-icon-layers-send-to-back
                    slot="icon"
                  ></sp-icon-layers-send-to-back>
                  Send to back
                </sp-menu-item>
              </sp-menu-group>
            </sp-action-menu>

            <sp-action-button
              quiet
              size="s"
              @click=${this.handleDelete}
              .disabled=${layersSelected.length === 0}
            >
              <sp-tooltip self-managed placement="bottom"> Delete </sp-tooltip>
              <sp-icon-delete slot="icon"></sp-icon-delete>
            </sp-action-button>
          </sp-action-group>
          <div class="container">
            ${(0, map_js_1.map)(sortedNodes, (node) => {
                // TODO: hierarchy
                // TODO: virtual scroll for better performance
                return (0, lit_1.html) `<ic-spectrum-layers-panel-item
                id=${this.generateLayersPanelItemId(node)}
                .node=${node}
                draggable
                @click=${(e) => this.handleSelect(e, node.id)}
                ?selected=${layersSelected.includes(node.id)}
                ?child=${!!node.parentId}
              ></ic-spectrum-layers-panel-item>`;
            })}
          </div>
        </section>`
            : null;
    }
};
exports.LayersPanel = LayersPanel;
LayersPanel.styles = (0, lit_1.css) `
    section {
      display: flex;
      flex-direction: column;
      background: var(--spectrum-gray-100);
      border-radius: var(--spectrum-corner-radius-200);

      margin: 4px;

      filter: drop-shadow(
        var(--spectrum-drop-shadow-color) 0px var(--spectrum-drop-shadow-y)
          var(--spectrum-drop-shadow-blur)
      );
    }

    h4 {
      padding: var(--spectrum-global-dimension-size-100);
      display: flex;
      align-items: center;
      justify-content: space-between;
      margin: 0;
    }

    .actions {
      padding: 4px;
      padding-top: 0;
    }

    .container {
      height: 300px;
      overflow: hidden;
      overflow-y: auto;
    }
  `;
__decorate([
    (0, context_1.consume)({ context: context_2.appStateContext, subscribe: true })
], LayersPanel.prototype, "appState", void 0);
__decorate([
    (0, context_1.consume)({ context: context_2.nodesContext, subscribe: true })
], LayersPanel.prototype, "nodes", void 0);
__decorate([
    (0, context_1.consume)({ context: context_2.apiContext, subscribe: true })
], LayersPanel.prototype, "api", void 0);
exports.LayersPanel = LayersPanel = __decorate([
    (0, decorators_js_1.customElement)('ic-spectrum-layers-panel')
], LayersPanel);
//# sourceMappingURL=layers-panel.js.map