"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InitCanvas = void 0;
const ecs_1 = require("@infinite-canvas-tutorial/ecs");
const event_1 = require("../event");
const API_1 = require("../API");
const context_1 = require("../context");
class InitCanvas extends ecs_1.System {
    constructor() {
        super();
        this.commands = new ecs_1.Commands(this);
        this.query((q) => q
            .using(ecs_1.ComputedCamera)
            .read.and.using(ecs_1.Canvas, ecs_1.Camera, ecs_1.Grid, ecs_1.Name, ecs_1.Cursor, ecs_1.Transform, ecs_1.Parent, ecs_1.Children, ecs_1.Renderable, ecs_1.Visibility, ecs_1.FillSolid, ecs_1.FillGradient, ecs_1.Stroke, ecs_1.Circle, ecs_1.Ellipse, ecs_1.Rect, ecs_1.Polyline, ecs_1.Path, ecs_1.Text, ecs_1.Selected, ecs_1.Opacity, ecs_1.DropShadow, ecs_1.ZIndex).write);
    }
    execute() {
        if (API_1.pendingCanvases.length) {
            API_1.pendingCanvases.forEach(({ container, canvas, camera }) => {
                const { appStateProvider, nodesProvider, apiProvider } = container;
                const stateManagement = new context_1.LitStateManagement(appStateProvider, nodesProvider);
                const api = new API_1.ExtendedAPI(stateManagement, this.commands, container);
                apiProvider.setValue(api);
                api.createCanvas(Object.assign(Object.assign({}, canvas), { api }));
                api.createCamera(camera);
                this.commands.execute();
                container.dispatchEvent(new CustomEvent(event_1.Event.READY, { detail: api }));
            });
            API_1.pendingCanvases.length = 0;
        }
    }
}
exports.InitCanvas = InitCanvas;
//# sourceMappingURL=InitCanvas.js.map